==> blue2-love-dougalston-1.0.7-415074.tar: assets/scripts/common.js <==
import Swiper from 'swiper';
import Magnific from 'magnific-popup';

const common = () => {
    new Swiper ('.news-swiper', {
        direction: 'horizontal',
        loop: true,
        spaceBetween: 50,
        slidesPerView: 3,
        breakpoints: {
            768: {
                centeredSlides: true,
                slidesPerView: 1,
            },
            992: {
                slidesPerView: 2,
            },
            1200: {
                slidesPerView: 3,
            }
        }
    });

    $('.navbar-toggler').on('click', function() {
        $('.navbar-toggler svg').toggleClass('fa-bars fa-times');
    });

    $('#trigger-video').on('click', function(e) {
        e.preventDefault();
        $('.main-video-block').addClass('active-video');
        $('#featured-video')[0].play();
    });

    $('.back').on('click', function(e) {
        e.preventDefault();
        $('.main-video-block').removeClass('active-video');
        $('#featured-video')[0].pause();
    });

    $('.scroll-to').on('click', function() {
        $('html,body').animate({
            scrollTop: $('.custom-flexible-section:nth-child(2)').offset().top }
        , 'slow');
    });

    $('.scroll-to-contact').on('click', function(e) {
        e.preventDefault();
        $('html,body').animate({
            scrollTop: $('.contact-section').offset().top }
        , 'slow');
    });

    if ($('.gallery-section').length) {
        $('.image-link').magnificPopup({
            type: 'image',
            gallery:{
                enabled:true
            }
        });
    }

    if ($('body#hero-is-video').length > 0) {
        const element = $('.hero-section');
        const height = $('.hero-section').offsetHeight;
        const top = $('.hero-section').offsetTop;
        const elementBottom = element.offsetTop + element.offsetHeight;
        console.log(element);
        console.log(elementBottom);
        console.log(height);
        console.log(top);
    }
};

export default common;

==> blue2-love-dougalston-1.0.14-785b05.tar: assets/scripts/common.js <==
import Swiper from 'swiper';
import Magnific from 'magnific-popup';

const common = () => {
    new Swiper ('.news-swiper', {
        direction: 'horizontal',
        loop: true,
        spaceBetween: 50,
        slidesPerView: 3,
        breakpoints: {
            768: {
                centeredSlides: true,
                slidesPerView: 1,
            },
            992: {
                slidesPerView: 2,
            },
            1200: {
                slidesPerView: 3,
            }
        }
    });

    $('.navbar-toggler').on('click', function() {
        $('.navbar-toggler svg').toggleClass('fa-bars fa-times');
    });

    $('#trigger-video').on('click', function(e) {
        e.preventDefault();
        $('.main-video-block').addClass('active-video');
        $('#featured-video')[0].play();
    });

    $('.back').on('click', function(e) {
        e.preventDefault();
        $('.main-video-block').removeClass('active-video');
        $('#featured-video')[0].pause();
    });

    $('.scroll-to').on('click', function() {
        $('html,body').animate({
            scrollTop: $('.custom-flexible-section:nth-child(2)').offset().top }
        , 'slow');
    });

    $('.scroll-to-contact').on('click', function(e) {
        e.preventDefault();
        $('html,body').animate({
            scrollTop: $('.contact-section').offset().top }
        , 'slow');
    });

    if ($('.gallery-section').length) {
        $('.image-link').magnificPopup({
            type: 'image',
            gallery:{
                enabled:true
            }
        });
    }

    if ($('body#hero-is-video').length > 0) {
        const element = $('.hero-section');  //record the elem so you don't crawl the DOM everytime
        const bottom = element.position().top + element.outerHeight(true);

        $(window).scroll(function() {
            const windowPosition = $(window).scrollTop();
            if (windowPosition  > bottom) {
                $('#hero-is-video .header-nav').addClass('fixed-video-nav');
                $('#hero-is-video .header-nav .logo-standard').show();
                $('#hero-is-video .header-nav .logo-white').hide();
            } else {
                $('#hero-is-video .header-nav').removeClass('fixed-video-nav');
                $('#hero-is-video .header-nav .logo-standard').hide();
                $('#hero-is-video .header-nav .logo-white').show();
            }
        });
    }
};

export default common;
